==> mdm-rpc-0.1.2-sources.jar: com/chinayanghe/msp/mdm/vo/region/RegionVo.java <==
package com.chinayanghe.msp.mdm.vo.region;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by Administrator on 2017/5/11 0011.
 */
public class RegionVo implements Serializable {
    private static final long serialVersionUID = 1772782687507490918L;
    //主键
    private String id;
    //行政区域编码
    private String regionCode;
    //行政区域名称
    private String regionName;
    //上级区域编码
    private String parentCode;
    //创建时间
    private Date createDate;
    //创建人ID
    private String createName;
    //修改时间
    private Date updateDate;
    //修改人
    private String updateName;
    //状态 0删除 1正常
    private Integer enableStatus;
    //有效开始时间
    private Date startDate;
    //有效结束时间
    private Date endDate;
    //操作类型
    private String flag;

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getRegionCode() {
        return regionCode;
    }

    public void setRegionCode(String regionCode) {
        this.regionCode = regionCode;
    }

    public String getRegionName() {
        return regionName;
    }

    public void setRegionName(String regionName) {
        this.regionName = regionName;
    }

    public String getParentCode() {
        return parentCode;
    }

    public void setParentCode(String parentCode) {
        this.parentCode = parentCode;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getFlag() {
        return flag;
    }

    public void setFlag(String flag) {
        this.flag = flag;
    }
}

==> mdm-rpc-0.1.7-sources.jar: com/chinayanghe/msp/mdm/vo/region/RegionVo.java <==
package com.chinayanghe.msp.mdm.vo.region;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by Administrator on 2017/5/11 0011.
 */
public class RegionVo implements Serializable {
    private static final long serialVersionUID = 1772782687507490918L;
    //主键
    private String id;
    //行政区域编码
    private String Code;
    //行政区域名称
    private String Name;
    //上级区域编码
    private String parentCode;
    //创建时间
    private Date createDate;
    //创建人ID
    private String createName;
    //修改时间
    private Date updateDate;
    //修改人
    private String updateName;
    //状态 0删除 1正常
    private Integer enableStatus;
    //区域层级AREA_LEVEL
    private Integer areaLevel;
    //操作类型AREA_LEVEL

    public Integer getAreaLevel() {
        return areaLevel;
    }

    public void setAreaLevel(Integer areaLevel) {
        this.areaLevel = areaLevel;
    }

    private String flag;

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return Code;
    }

    public void setCode(String code) {
        Code = code;
    }

    public String getName() {
        return Name;
    }

    public void setName(String name) {
        Name = name;
    }

    public String getParentCode() {
        return parentCode;
    }

    public void setParentCode(String parentCode) {
        this.parentCode = parentCode;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public String getFlag() {
        return flag;
    }

    public void setFlag(String flag) {
        this.flag = flag;
    }
}
